==> aar_multi_chip-1.1.71-sources.jar: com/xdja/multichip/process/tfcard/TfCardEventReceiver.java <==
package com.xdja.multichip.process.tfcard;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.util.Log;

import com.xdja.multichip.MultiJniApiConfig;
import com.xdja.multichip.utils.FuncUtils;

/**
 * @author: zhangxiaolong@xdja.com <br/>
 * date:   2018/5/16 <br/>
 */
public class TfCardEventReceiver extends BroadcastReceiver {
    private static final String tag = TfCardEventReceiver.class.getSimpleName();

    @Override
    public void onReceive(Context context, Intent intent) {
        Log.v(tag, "xdjatfprocessService BroadcastReceiver");

        if(intent == null){
            Log.v("tag","TfCardEventReceiver intent null");
            return;
        }

        //add by zhangxiaolong 2018-12-12 用于判断配置文件中是否允许启动子进程,目前先不杀死，之后研究如何杀死
        if (!MultiJniApiConfig.getInstance(context).judgeChipCanUse(TFChipForCall.NAME_PROCESS_TF)) {
            return;
        }

        //2018年7月24日11:04:34 weizg
        //安全接入反馈问题：同时又安全接入和芯片管家时，插拔tf卡，安全接入的tf receiver会收到广播，启动进程
        //再次插入后，该receiver依然会响应，会尝试打开卡，如果当前tf卡非支持多应用打开的cos，
        // 会出现芯片管家打不开的卡的情况

        //判断如果当前进程非芯片管家，并且芯片管家存在，则该receiver不做任何处理
        if(!FuncUtils.PKG_SAFE_KEYSERVICE.equals(context.getPackageName())
                && FuncUtils.isApkExist(context,FuncUtils.PKG_SAFE_KEYSERVICE)){
            return;
        }

        //注意：当TF卡卸载或移除（从卡槽拔出），某系统上（魅族）会杀死打开过TF的进程；
        //新增了Intent.ACTION_MEDIA_REMOVED广播类型，因为在TF快速插入，再拔出时，系统只发出了该类型广播
        //tf卡被弹出（正常卸载或者强制移除卡）
        if (Intent.ACTION_MEDIA_EJECT.equals(intent.getAction()) ||
                Intent.ACTION_MEDIA_REMOVED.equals(intent.getAction())) {
            Log.v(tag, "tf卡移除");
            //确定那个卡被移除，然后广播通知；信息列表
            TFJniApiHandle.getInstance().handleMediaRemoved(context.getApplicationContext());

        } else if (Intent.ACTION_MEDIA_MOUNTED.equals(intent.getAction())) {
            //tf卡被挂载
            Log.v(tag, "tf卡被挂载");
            TFJniApiHandle.getInstance().handleMediaMounted(context.getApplicationContext());
        }
    }
}

==> aar_multi_chip-1.1.220-sources.jar: com/xdja/multichip/process/tfcard/TfCardEventReceiver.java <==
package com.xdja.multichip.process.tfcard;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.util.Log;

import com.xdja.multichip.MultiJniApiConfig;
import com.xdja.multichip.utils.FuncUtils;

/**
 * @author: zhangxiaolong@xdja.com <br/>
 * date:   2018/5/16 <br/>
 */
public class TfCardEventReceiver extends BroadcastReceiver {
    private static final String TAG = TfCardEventReceiver.class.getSimpleName();

    @Override
    public void onReceive(Context context, Intent intent) {
        Log.v(TAG, "xdjatfprocessService BroadcastReceiver");

        if(intent == null){
            Log.v("tag","TfCardEventReceiver intent null");
            return;
        }

        //add by zhangxiaolong 2018-12-12 用于判断配置文件中是否允许启动子进程,目前先不杀死，之后研究如何杀死
        if (!MultiJniApiConfig.getInstance(context).judgeChipCanUse(TFChipForCall.NAME_PROCESS_TF)) {
            return;
        }

        //2018年7月24日11:04:34 weizg
        //安全接入反馈问题：同时又安全接入和芯片管家时，插拔tf卡，安全接入的tf receiver会收到广播，启动进程
        //再次插入后，该receiver依然会响应，会尝试打开卡，如果当前tf卡非支持多应用打开的cos，
        // 会出现芯片管家打不开的卡的情况

        //判断如果当前进程非芯片管家，并且芯片管家存在，则该receiver不做任何处理
        if(!FuncUtils.PKG_SAFE_KEYSERVICE.equals(context.getPackageName())
                && FuncUtils.isApkExist(context,FuncUtils.PKG_SAFE_KEYSERVICE)){
            return;
        }

        //注意：当TF卡卸载或移除（从卡槽拔出），某系统上（魅族）会杀死打开过TF的进程；
        //新增了Intent.ACTION_MEDIA_REMOVED广播类型，因为在TF快速插入，再拔出时，系统只发出了该类型广播
        //tf卡被弹出（正常卸载或者强制移除卡）
        if (Intent.ACTION_MEDIA_EJECT.equals(intent.getAction()) ||
                Intent.ACTION_MEDIA_REMOVED.equals(intent.getAction())) {
            Log.v(TAG, "tf卡移除");
            //确定那个卡被移除，然后广播通知；信息列表
            TFJniApiHandle.getInstance().handleMediaRemoved(context.getApplicationContext());

        } else if (Intent.ACTION_MEDIA_MOUNTED.equals(intent.getAction())) {
            //tf卡被挂载
            Log.v(TAG, "tf卡被挂载");
            TFJniApiHandle.getInstance().handleMediaMounted(context.getApplicationContext());
        }
    }
}
